@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# gsnodegraph Copyright 2019-2021 by Noah Rahm and contributors
+# gsnodegraph Copyright 2019-2022 by Noah Rahm and contributors
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -42,10 +42,16 @@ ID_CONTEXTMENU_DESELECTALLNODES = wx.NewIdRef()
 ID_CONTEXTMENU_SELECTALLNODES = wx.NewIdRef()
 
 
-class NodeGraph(wx.ScrolledCanvas):
-    def __init__(self, parent, registry, *args, **kwds):
+class NodeGraphBase(wx.ScrolledCanvas):
+    def __init__(self, parent, registry, config, *args, **kwds):
+        kwds["style"] = kwds.get("style", 0) | wx.DEFAULT_FRAME_STYLE
+        wx.ScrolledCanvas.__init__(self, parent, *args, **kwds)
+        
         self.parent = parent
         self.node_registry = registry
+        self.node_datatypes = config["node_datatypes"]
+        self.node_categories = config["node_categories"]
+        self.image_datatype = config["image_datatype"]
 
         self.matrix = ZMatrix()
         self.identity = ZMatrix()
@@ -78,9 +84,6 @@ class NodeGraph(wx.ScrolledCanvas):
         # Init the add node button
         self.addnode_btn = AddNodeBtn(self)
 
-        kwds["style"] = kwds.get("style", 0) | wx.DEFAULT_FRAME_STYLE
-        wx.ScrolledCanvas.__init__(self, parent, *args, **kwds)
-
         # Event bindings
         self.Bind(wx.EVT_PAINT, self.OnPaint)
         self.Bind(wx.EVT_ERASE_BACKGROUND, lambda x: None)
@@ -757,14 +760,14 @@ class NodeGraph(wx.ScrolledCanvas):
         src_socket.wires.append(wire)
         dst_socket.wires.append(wire)
 
-        dst_socket.node.EditParameter(dst_socket.idname, self.nodes[src_socket.node.id])
+        dst_socket.node.EditConnection(dst_socket.idname, self.nodes[src_socket.node.id], src_socket.idname)
         self.SendNodeConnectEvent()
 
     def DisconnectNodes(self, src_socket, dst_socket):
         for wire in self.wires:
             if wire.srcsocket is src_socket and wire.dstsocket is dst_socket:
                 self.wires.remove(wire)
-                wire.dstsocket.node.EditParameter(wire.dstsocket.idname, None)
+                wire.dstsocket.node.EditConnection(wire.dstsocket.idname, None, None)
 
         self.SendNodeDisconnectEvent()
 
