@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# gsnodegraph Copyright 2019-2021 by Noah Rahm and contributors
+# gsnodegraph Copyright 2019-2022 by Noah Rahm and contributors
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,7 +20,7 @@ from gsnodegraph.assets.bitmaps import ICON_IMAGE
 
 from .socket import NodeSocket
 from ..constants import (NODE_DEFAULT_WIDTH, NODE_DEFAULT_HEIGHT,
-                         NODE_HEADER_MUTED_COLOR, NODE_HEADER_CATEGORY_COLORS,
+                         NODE_HEADER_MUTED_COLOR,
                          SOCKET_INPUT, SOCKET_OUTPUT, NODE_THUMB_PADDING, NODE_Y_PADDING,
                          NODE_NORMAL_COLOR, NODE_MUTED_COLOR, NODE_THUMB_BORDER_COLOR,
                          NODE_BORDER_NORMAL_COLOR, NODE_BORDER_SELECTED_COLOR)
@@ -28,33 +28,51 @@ from ..assets import (ICON_BRUSH_CHECKERBOARD, ICON_IMAGE)
 
 
 class NodeBase(object):
-    def __init__(self, nodegraph, _id):
+    def __init__(self, nodegraph, id):
         self.nodegraph = nodegraph
-        self.id = _id
+        self.id = id
         self.idname = None
         self.pos = wx.Point(0, 0)
         self.size = wx.Size(NODE_DEFAULT_WIDTH, NODE_DEFAULT_HEIGHT)
+        self.header_color = wx.Colour("#242424")
 
         self.expanded = False
         self.selected = False
         self.active = False
         self.muted = False
+        self.is_output = False
 
         self.sockets = []
-        self.parameters = {}
+        self.properties = {}
+        self.outputs = {}
 
-        self.is_output = False
         self.label = ""
-        self.category = "INPUT"
-        self.header_color = wx.Colour(NODE_HEADER_CATEGORY_COLORS["INPUT"])
+        self.category = None
+        self.has_thumbnail = False
 
         self.thumbnail = self.CreateEmptyBitmap()
         self.expandicon_bmp = ICON_IMAGE.GetBitmap()
         self.checkerboard_bmp = ICON_BRUSH_CHECKERBOARD.GetBitmap()
 
+    @property
+    def NodeGraph(self):
+        return self.nodegraph
+
+    @property
+    def NodeDatatypes(self):
+        return self.nodegraph.node_datatypes
+
+    @property
+    def NodeCategories(self):
+        return self.nodegraph.node_categories
+
+    @property
+    def NodeImageDatatype(self):
+        return self.nodegraph.image_datatype
+
     def Init(self, idname) -> None:
         self.InitSockets()
-        self.Initheader_color()
+        self.InitHeaderColor()
         self.InitSize()
         self.SetIdName(idname)
 
@@ -64,9 +82,6 @@ class NodeBase(object):
         img.InitAlpha()
         return img.ConvertToBitmap()
 
-    def NodeOutputDatatype(self) -> str:
-        return "RGBAIMAGE"
-
     def AddSocket(self, label, color, direction) -> None:
         self.ArrangeSockets()
 
@@ -83,33 +98,32 @@ class NodeBase(object):
             if socket.HitTest(pos - self.pos):
                 return socket
 
-    def EditParameter(self, idname, value):
+    def EditConnection(self, name, binding, socket):
         pass
 
-    def Initheader_color(self) -> None:
-        self.header_color = wx.Colour(NODE_HEADER_CATEGORY_COLORS[self.GetCategory()])
+    def InitHeaderColor(self) -> None:
+        self.header_color = wx.Colour(self.NodeCategories[self.GetCategory()])
 
     def InitSockets(self) -> None:
         sockets = []
         ins = []
         outs = []
 
-        # Create a list of input sockets with the format:
+        # Create a list of input and output sockets with the format:
         # [(label, idname, datatype), ...]
-        for param_id in self.parameters:
-            param = self.parameters[param_id]
-            ins.append((param.label, param.idname, param.datatype))
+        for prop_id in self.properties:
+            prop = self.properties[prop_id]
+            if prop.exposed and prop.can_be_exposed:
+                ins.append((prop.label, prop.idname, prop.datatype))
 
         if self.IsOutputNode() is not True:
-            # TODO: eventually, we want to have the ability to edit the label
-            data_type = self.NodeOutputDatatype()
-            if data_type == "RGBAIMAGE":
-                idname = "output_image"
-                label = "Image"
-            else:
-                idname = "output_value"
-                label = "Value"
-            outs = [(label, idname, data_type)]
+            for output_id in self.outputs:
+                output = self.outputs[output_id]
+                outs.append((output.label, output.idname, output.datatype))
+                # If there is an image datatype then we know there 
+                # should be a thumbnail for this node.
+                if output.datatype == self.NodeImageDatatype:
+                    self.has_thumbnail = True
 
         x, y, w, h = self.GetRect()
         x, y = self.pos
@@ -123,12 +137,13 @@ class NodeBase(object):
                 socket_type = SOCKET_OUTPUT  # Socket type OUT
 
             # We keep track of where the last socket is placed
-            self.lastsocket_pos = 60 + 12 * i
+            self.lastsocket_pos = 60 + 14 * i
 
             # Create the node sockets
             socket = NodeSocket(label=p[0], idname=p[1], datatype=p[2],
                                 node=self, direction=socket_type)
-            socket.pos = wx.Point(x, 40 + (19 * i))
+            socket.pos = wx.Point(x, 45 + (19 * i))
+            socket.SetColor(self.NodeDatatypes[socket.datatype])
             sockets.append(socket)
 
         self.sockets = sockets
@@ -150,10 +165,7 @@ class NodeBase(object):
             self.SetSize(self.normal_size)
 
     def HasThumbnail(self) -> bool:
-        if self.NodeOutputDatatype() == "RGBAIMAGE":
-            return True
-        else:
-            return False
+        return self.has_thumbnail
 
     def IsOutputNode(self) -> bool:
         """ Override method to set whether the node is the output or not. """
@@ -271,11 +283,11 @@ class NodeBase(object):
             header_color = wx.Colour(self.header_color).ChangeLightness(70)
             bottom_color = wx.Colour(self.header_color).ChangeLightness(55)
         dc.SetBrush(wx.Brush(header_color))
-        dc.DrawRoundedRectangle(x+1, y+1, w-2, 24, 3)
+        dc.DrawRoundedRectangle(x+1, y+1, w-2, 25, 3)
 
         # Bottom border of the node header (to cover up the rounded bottom)
         dc.SetBrush(wx.Brush(bottom_color))
-        dc.DrawRectangle(x+1, y+23, w-2, 2)
+        dc.DrawRectangle(x+1, y+24, w-2, 2)
 
         # Node name label
         if self.IsMuted():
@@ -290,7 +302,7 @@ class NodeBase(object):
 
         # Expand node thumbnail icon
         if self.HasThumbnail() == True and self.IsMuted() != True:
-            self.expandicon_rect = wx.Rect(x+NODE_DEFAULT_WIDTH-28, y+4, 16, 16)
+            self.expandicon_rect = wx.Rect(x+NODE_DEFAULT_WIDTH-28, y+5, 16, 16)
             dc.DrawBitmap(self.expandicon_bmp, self.expandicon_rect[0],
                         self.expandicon_rect[1], True)
 
